@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 
-our $VERSION = '0.163';
+our $VERSION = '0.164';
 
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -172,7 +172,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.163
+version 0.164
 
 =head1 SYNOPSIS
 
@@ -237,10 +237,6 @@ following F<weaver.ini>, minus some optimizations:
     title = SUPPORT
     main_module_only = 0
     text = <template>
-    [AllowOverride / allow override SUPPORT]
-    header_re = ^(SUPPORT|BUGS)\b
-    action = prepend
-    match_anywhere = 0
 
     [Authors]
     [AllowOverride / allow override AUTHOR]
@@ -274,10 +270,6 @@ This is also equivalent (other than section ordering) to:
     title = SUPPORT
     main_module_only = 0
     text = <template>
-    [AllowOverride / allow override SUPPORT]
-    header_re = ^(SUPPORT|BUGS)
-    action = prepend
-    match_anywhere = 0
 
     [Authors]
     [Contributors]
@@ -298,6 +290,7 @@ This F<weaver.ini> will let you use a custom C<COPYRIGHT AND LICENCE> section an
     [AllowOverride / OverrideLegal]
     header_re = ^COPYRIGHT
     match_anywhere = 1
+    action = append
 
 =head1 ADDING STOPWORDS FOR SPELLING TESTS
 
